@@ -1,5 +1,5 @@
 from flask.testing import FlaskClient
-from eagle.app import create_app
+from flask_theme_adminlte3.app import create_app
 import pytest
 
 def test_configfile_not_exists(client:FlaskClient):
